@@ -1,5 +1,5 @@
 import pandas as pd
-from Common.npd_data import get_ww_tickers
+from WhaleWisdom.Common.npd_data import get_ww_tickers
 
 def get_ticker_count(data):
 
